# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import argparse
import os
import json


def parse_args():
    parser = argparse.ArgumentParser()
    parser.add_argument('--dataset_path', type=str, default='./data')
    args = parser.parse_args()
    return args

def trans_to_videoclas(args):
    """
    Convert json in file into paddlex videoclas format.
    """
    src_label_path = os.path.join(args.dataset_path, "ai.json")
    dst_label_path = os.path.join(args.dataset_path, "train.txt")
    dst_classmap_path = os.path.join(args.dataset_path, "label.txt")
    dst_label_path_fp = open(dst_label_path, "w")
    data = json.load(open(src_label_path, 'r'))
    label_dict = {}
    label_idx = 0
    for video_dict in data:
        videoname = video_dict['videoName']
        video_label = video_dict['videoxLabels']
        if len(video_label)>0:
            label = video_label[0]['label']
            if len(label)>0:
                class_label = label[0]['label']
                if class_label not in label_dict:
                    label_dict[class_label] = label_idx
                    label_idx += 1
    with open(dst_classmap_path, "w") as fp:
        for key, value in label_dict.items():
            fp.writelines("{} {}\n".format(value, key))
    
    for video_dict in data:
        video_name = video_dict['videoName']
        video_label = video_dict['videoxLabels']
        if len(video_label)>0:
            label = video_label[0]['label']
            if len(label)>0:
                class_label = label[0]['label']
                class_label_id = label_dict[class_label]
                dst_label_path_fp.writelines("{} {}\n".format(video_name, class_label_id ))
    dst_label_path_fp.close()      
                
if __name__ == "__main__":
    args = parse_args()
    trans_to_videoclas(args)
